# Examples

This directory contains a few usage examples for Uplink. If you notice a need for a particular example, 
feel free to [open an Issue](https://github.com/prkumar/uplink/issues/new). Or, to contribute your own example,
[open a Pull Request](https://github.com/prkumar/uplink/compare) -- please include a README detailing the example's
purpose and add a short description to the "Table of Contents" section below.

## Table of Contents

- **[async-requests](async-requests)**: Use [`aiohttp`](https://github.com/aio-libs/aiohttp) or 
  [`twisted`](https://github.com/twisted/twisted) for non-blocking I/O
- **[github-api](github-api)**: Consume the GitHub API to serve a downstream HTTP service with Flask.
- **[handler_callbacks](handler_callbacks)**: Handle client errors and responses using callbacks.
- **[marshmallow](marshmallow)**: Create clients that automatically deserialize responses with the 
  help of [`marshmallow`](https://marshmallow.readthedocs.io/en/latest/).
